Page({
  data: {
    countDown: 10, // 假设录像时间为10秒
    cameraDirection: 'back',
    flashMode: 'off',
  },
  switchCamera: function() {
    this.setData({
      cameraDirection: this.data.cameraDirection === 'back' ? 'front' : 'back'
    });
  },
  toggleFlash: function() {
    this.setData({
      flashMode: this.data.flashMode === 'off' ? 'torch' : 'off'
    });
  },

  onLoad: function() {
    wx.authorize({
      scope: 'scope.record',
      success: () => { // 使用箭头函数
        this.countDownFunc();
        this.startRecord();
      },
      fail: () => {
        this.promptForCameraPermission();
      }
    });
  },

  countDownFunc: function() {
    let that = this;
    let countDownNum = that.data.countDown; //获取倒计时初始值
    //每隔一秒执行一次
    that.countDownInterval = setInterval(function () {
      countDownNum--;
      that.setData({
        countDown: countDownNum
      })
      if (countDownNum == 0) {
        clearInterval(that.countDownInterval);
        // 倒计时为0时停止录像
        that.stopRecord();
      }
    }, 1000)
  },

  startRecord: function() {
    this.cameraCtx = wx.createCameraContext();
    this.cameraCtx.startRecord({
      success: () => {
        console.log('开始录像');
      },
      fail: (err) => {
        console.log('录像失败', err);
      }
    });
  },

  promptForCameraPermission: function() {
    // 用户拒绝授权，可以提示用户打开设置页授权
   wx.showModal({
     title: '提示',
     content: '需要您授权摄像头权限',
     showCancel: false,
     success(modalSuccess) {
       wx.openSetting({
         success(settingdata) {
           if (settingdata.authSetting['scope.record']) {
             // 用户打开设置页授权成功
           } else {
             // 用户打开设置页仍然拒绝授权
           }
         }
       });
     }
   });
 },

  stopRecord: function() {
    this.cameraCtx.stopRecord({
      success: (res) => {
        console.log('录像结束', res);
        const tempFilePath = res.tempVideoPath;
        // 调用上传视频文件的函数
        this.uploadVideo(tempFilePath);
      }
    });
  },

  // 其他函数（uploadVideo等）
  uploadVideo: function(filePath) {
    const that = this;
    wx.uploadFile({
      url: 'http://123.57.65.209:5000/upload', // 替换为服务器上传接口URL
      filePath: filePath,
      name: 'file', // 服务器端通过此名称接收文件

      success: function(res) {
        const data = JSON.parse(response.data);
        console.log(data.result);  // 输出处理结果
        // 可以在这里处理上传成功后的逻辑
        // 上传完成后返回主页面
        //wx.navigateBack();
      },
      fail: function(error) {
        console.log('上传失败', error);
        // 上传失败也返回主页面，或根据需要处理错误
        //wx.navigateBack();
      }
    });
    wx.navigateBack();
  },

  cameraError: function(e) {
    console.log(e.detail.errMsg);
    wx.showModal({
      title: '摄像头错误',
      content: '请检查摄像头权限设置。',
      showCancel: false,
      success: function() {
        wx.navigateBack(); // 权限错误时返回上一页
      }
    });
  },

  onUnload: function() {
    // 页面卸载时清除计时器
    clearInterval(this.countDownInterval);
  },

});
